<?php

namespace Litecms\Person\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Person\Interfaces\PersonRepositoryInterface;

class PersonPublicController extends BaseController
{
    // use PersonWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Person\Interfaces\PersonRepositoryInterface $person
     *
     * @return type
     */
    public function __construct(PersonRepositoryInterface $person)
    {
        $this->repository = $person;
        parent::__construct();
    }

    /**
     * Show person's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $people = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$person::$person.names'))
            ->view('$person::public.person.index')
            ->data(compact('$people'))
            ->output();
    }

    /**
     * Show person's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $people = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$person::$person.names'))
            ->view('$person::public.person.index')
            ->data(compact('$people'))
            ->output();
    }

    /**
     * Show person.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $person = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$person->name . trans('$person::$person.name'))
            ->view('$person::public.person.show')
            ->data(compact('$person'))
            ->output();
    }

}
