<?php

namespace Litecms\Person\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Person\Models\Person;

class PersonPolicy
{

    /**
     * Determine if the given user can view the person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function view(UserPolicy $user, Person $person)
    {
        if ($user->canDo('person.person.view') && $user->isAdmin()) {
            return true;
        }

        return $person->user_id == user_id() && $person->user_type == user_type();
    }

    /**
     * Determine if the given user can create a person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('person.person.create');
    }

    /**
     * Determine if the given user can update the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function update(UserPolicy $user, Person $person)
    {
        if ($user->canDo('person.person.edit') && $user->isAdmin()) {
            return true;
        }

        return $person->user_id == user_id() && $person->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Person $person)
    {
        return $person->user_id == user_id() && $person->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Person $person)
    {
        if ($user->canDo('person.person.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given person.
     *
     * @param UserPolicy $user
     * @param Person $person
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Person $person)
    {
        if ($user->canDo('person.person.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
